*************
Core of Oríon
*************

.. automodule:: orion.core
   :members:

.. toctree::
   :maxdepth: 2
   :caption: Core modules of Oríon

   core/worker
   core/evc
   core/io
   core/cli
   core/utils
